summaryrefslogtreecommitdiff
path: root/lisp/emacs-lisp
diff options
context:
space:
mode:
Diffstat (limited to 'lisp/emacs-lisp')
-rw-r--r--lisp/emacs-lisp/autoload.el5
-rw-r--r--lisp/emacs-lisp/bytecomp.el18
-rw-r--r--lisp/emacs-lisp/edebug.el22
-rw-r--r--lisp/emacs-lisp/lisp-mode.el5
-rw-r--r--lisp/emacs-lisp/ring.el5
5 files changed, 33 insertions, 22 deletions
diff --git a/lisp/emacs-lisp/autoload.el b/lisp/emacs-lisp/autoload.el
index c1740717e69..c8f73cf1ddf 100644
--- a/lisp/emacs-lisp/autoload.el
+++ b/lisp/emacs-lisp/autoload.el
@@ -1,11 +1,10 @@
;;; autoload.el --- maintain autoloads in loaddefs.el.
+;;; Copyright (C) 1991, 1992 Free Software Foundation, Inc.
+;;;
;; Author: Roland McGrath <roland@gnu.ai.mit.edu>
-;; Last-Modified: 24 Jun 1992
;; Keyword: internal
-;;; Copyright (C) 1991, 1992 Free Software Foundation, Inc.
-;;;
;;; This program is free software; you can redistribute it and/or modify
;;; it under the terms of the GNU General Public License as published by
;;; the Free Software Foundation; either version 2, or (at your option)
diff --git a/lisp/emacs-lisp/bytecomp.el b/lisp/emacs-lisp/bytecomp.el
index 583fd60b392..0a781d33344 100644
--- a/lisp/emacs-lisp/bytecomp.el
+++ b/lisp/emacs-lisp/bytecomp.el
@@ -1,16 +1,15 @@
;;; bytecomp.el --- compilation of Lisp code into byte code.
+;;; Copyright (C) 1985, 1986, 1987, 1992 Free Software Foundation, Inc.
+
;; Author: Jamie Zawinski <jwz@lucid.com>
;; Hallvard Furuseth <hbf@ulrik.uio.no>
-;; Last-Modified: 15 Jul 1992
;; Keywords: internal
;; Subsequently modified by RMS.
(defconst byte-compile-version "FSF 2.1")
-;;; Copyright (C) 1985, 1986, 1987, 1992 Free Software Foundation, Inc.
-
;; This file is part of GNU Emacs.
;; GNU Emacs is free software; you can redistribute it and/or modify
@@ -245,8 +244,17 @@ of `message.'")
(defconst byte-compile-warning-types '(redefine callargs free-vars unresolved))
(defvar byte-compile-warnings (not noninteractive)
"*List of warnings that the byte-compiler should issue (t for all).
-Valid elements of this list are `callargs', `redefine', `free-vars',
-and `unresolved'.")
+Valid elements of this list are:
+`free-vars' (references to variables not in the
+ current lexical scope)
+`unresolved' (calls to unknown functions)
+`callargs' (lambda calls with args that don't
+ match the lambda's definition)
+`redefine' (function cell redefined from
+ a macro to a lambda or vice versa,
+ or redefined to take other args)
+This variable defaults to nil in -batch mode, which is
+slightly faster.")
(defvar byte-compile-generate-call-tree nil
"*Non-nil means collect call-graph information when compiling.
diff --git a/lisp/emacs-lisp/lisp-mode.el b/lisp/emacs-lisp/lisp-mode.el
index 2ffe6cfb6b1..76d34d7a0e6 100644
--- a/lisp/emacs-lisp/lisp-mode.el
+++ b/lisp/emacs-lisp/lisp-mode.el
@@ -1,11 +1,10 @@
;;; lisp-mode.el --- Lisp mode, and its idiosyncratic commands.
+;; Copyright (C) 1985 Free Software Foundation, Inc.
+
;; Maintainer: FSF
-;; Last-Modified: 03 Jun 1992
;; Keywords: lisp, languages
-;; Copyright (C) 1985 Free Software Foundation, Inc.
-
;; This file is part of GNU Emacs.
;; GNU Emacs is free software; you can redistribute it and/or modify
diff --git a/lisp/emacs-lisp/ring.el b/lisp/emacs-lisp/ring.el
index 066b3b6b64a..9951221c1d8 100644
--- a/lisp/emacs-lisp/ring.el
+++ b/lisp/emacs-lisp/ring.el
@@ -1,11 +1,10 @@
;;; ring.el --- handle rings of marks
+;; Copyright (C) 1992 Free Software Foundation, Inc.
+
;; Maintainer: FSF
-;; Last-Modified: 22 Apr 1991
;; Keywords: extensions
-;; Copyright (C) 1992 Free Software Foundation, Inc.
-
;; This file is part of GNU Emacs.
;; GNU Emacs is free software; you can redistribute it and/or modify
diff --git a/lisp/emacs-lisp/edebug.el b/lisp/emacs-lisp/edebug.el
index d60f2608103..6c4437a822d 100644
--- a/lisp/emacs-lisp/edebug.el
+++ b/lisp/emacs-lisp/edebug.el
@@ -1,7 +1,10 @@
-;;; edebug.el --- a source-level debugger for emacs lisp.
+;;; edebug.el --- a source-level debugger for emacs lisp
;; Copyright (C) 1988, 1989, 1990, 1991 Free Software Foundation, Inc
+;; Author: Daniel LaLiberte <liberte@cs.uiuc.edu>
+;; Keywords: lisp, tools
+
;; This file is part of GNU Emacs.
;; GNU Emacs is distributed in the hope that it will be useful,
@@ -19,8 +22,9 @@
;; file named COPYING. Among other things, the copyright notice
;; and this notice must be preserved on all copies.
-;;;================================================================
-;;; This minor mode allows programmers to step through elisp source
+;;;; Commentary:
+
+;;; This minor mode allows programmers to step through Emacs Lisp source
;;; code while executing, set breakpoints, etc. See the texinfo
;;; document (being constructed...) for more detailed instructions
;;; than contained here. Send me your enhancement, ideas, bugs, or
@@ -152,7 +156,7 @@
;;;
;;; Revision 1.4 89/02/14 22:58:34 liberte
;;; Fix broken breakpointing.
;;; Temporarily widen elisp buffer during edebug.
;;;
;;; Revision 1.3 89/01/30 00:26:09 liberte
;;; More bug fixes for cond and let.
@@ -186,6 +190,8 @@
;; Use the "?" command in edebug to describe other commands.
;; See edebug.texinfo for more instructions.
+;;; Code:
+
;;; Options
;;; -------
@@ -198,7 +204,7 @@ If nil, eval-region evaluates normally, but eval-defun with prefix arg
uses edebug-defun. eval-region is called by eval-defun, eval-last-sexp,
and eval-print-last-sexp.
-You may wish to make this variable local to each elisp buffer by calling
+You may wish to make this variable local to each Emacs Lisp buffer by calling
(make-local-variable 'edebug-all-defuns) in your emacs-lisp-mode-hook.
You can use the function edebug-all-defuns to toggle its value.")
@@ -266,7 +272,7 @@ edebug-print-trace-exit.")
(defun edebug-last-sexp ()
"Return the last sexp before point in current buffer.
-Assumes elisp syntax is active."
+Assumes Emacs Lisp syntax is active."
(car
(read-from-string
(buffer-substring
@@ -852,7 +858,7 @@ may be one of the following:
(throw 'no-match nil))
(edebug-syntax-error "%s is not %s" form arg))))
;; for loop defined in elisp manual
(put 'for 'edebug-form-hook
'(symbolp 'from form 'to form 'do &rest form))
@@ -2243,7 +2249,7 @@ print value into current buffer."
(defun edebug-mode ()
- "Mode for elisp buffers while in edebug. Under construction.
+ "Mode for Emacs Lisp buffers while in edebug. Under construction.
There are both buffer local and global key bindings to several
functions. E.g. edebug-step-through is bound to
@@ -152,7 +156,7 @@
;;; Revision 1.4 89/02/14 22:58:34 liberte
;;; Fix broken breakpointing.
-;;; Temporarily widen elisp buffer during edebug.
+;;; Temporarily widen Emacs Lisp buffer during edebug.
;;;
;;; Revision 1.3 89/01/30 00:26:09 liberte
@@ -852,7 +858,7 @@ may be one of the following:
(throw 'no-match nil))
(edebug-syntax-error "%s is not %s" form arg))))
-;; for loop defined in elisp manual
+;; for loop defined in Emacs Lisp manual
(put 'for 'edebug-form-hook
'(symbolp 'from form 'to form 'do &rest form))